@@ -15,21 +15,25 @@
 #' @examples 
 #' library(phenology)
 #' # Read a file with data
-#' # Gratiot<-read.delim("http://max2.ese.u-psud.fr/epc/conservation/BI/Complete.txt", , header=FALSE)
+#' \dontrun{
+#' Gratiot<-read.delim("http://max2.ese.u-psud.fr/epc/conservation/BI/Complete.txt", header=FALSE)
+#' }
 #' data(Gratiot)
 #' # Generate a formatted list named data_Gratiot 
-#' data_Gratiot<-add_phenology(Gratiot, name="Complete", reference=as.Date("2001-01-01"), format="%d/%m/%Y")
+#' data_Gratiot<-add_phenology(Gratiot, name="Complete", 
+#' 		reference=as.Date("2001-01-01"), format="%d/%m/%Y")
 #' # Generate initial points for the optimisation
 #' parg<-par_init(data_Gratiot, parametersfixed=NULL)
 #' # Run the optimisation
-#' ## not run
-#' # result_Gratiot<-fit_phenology(data=data_Gratiot, parametersfit=parg, parametersfixed=NULL, trace=1)
-#' ## end not run
+#' \dontrun{
+#' result_Gratiot<-fit_phenology(data=data_Gratiot, 
+#' 		parametersfit=parg, parametersfixed=NULL, trace=1)
+#' }
 #' data(result_Gratiot)
 #' # Generate set of priors for Bayesian analysis
-#' ## not run
-#' ## pmcmc <- phenology_MHmcmc_p(result_Gratiot)
-#' ## end not run
+#' \dontrun{
+#' pmcmc <- phenology_MHmcmc_p(result_Gratiot)
+#' }
 #' pmcmc <- structure(c("dunif", "dunif", "dunif", "dunif", "dunif", "dunif", 
 #' "dunif", "dunif", "0", "0", "0", "0", "0", "0", "0", "0", "200", 
 #' "365", "200", "50", "200", "5", "5", "10", "2", "2", "2", "2", 
@@ -41,12 +45,12 @@
 #' "Peak", "LengthE", "Flat", "Max_Gratiot", "MinB_Gratiot", "MinE_Gratiot", 
 #' "Theta"), c("Density", "Prior1", "Prior2", "SDProp", "Min", "Max", 
 #' "Init")))
-#' ## not run
-#' # res_mcmc <- phenology_MHmcmc(result = result_Gratiot, n.iter = 10000, 
-#' # parametersMCMC = pmcmc, n.chains = 1, n.adapt = 0, thin = 1, trace = FALSE)
-#' # data(res_mcmc)
-#' # plot(res_mcmc, parameters=3, xlim=c(230, 330))
-#' ## end not run
+#' \dontrun{
+#' res_mcmc <- phenology_MHmcmc(result = result_Gratiot, n.iter = 10000, 
+#' 		parametersMCMC = pmcmc, n.chains = 1, n.adapt = 0, thin = 1, trace = FALSE)
+#' data(res_mcmc)
+#' plot(res_mcmc, parameters=3, xlim=c(230, 330))
+#' }
 #' @method plot mcmcComposite
 #' @export
 
@@ -110,7 +114,7 @@ vals <- mcmc[[chain]][,variable]
 	x2 <- (par("usr")[1]+par("usr")[2]*26)/27
 	x1 <- x2*26-par("usr")[2]/0.04
 
-	plot(x1:x2, get(Parameters[variable, "Density"])(x1:x2, 
+	plot(seq(from=x1, to=x2, length=100), get(Parameters[variable, "Density"])(seq(from=x1, to=x2, length=100), 
 	as.numeric(Parameters[variable,"Prior1"]),as.numeric(Parameters[variable,"Prior2"])), type="l", col="red", xlab="", ylab="", axes = FALSE, xlim=c(x1, x2), main="")
 
 	legend("topright", c("Prior", "Posterior"), lty=1, col=c('red', 'black'), bty = "n")
